package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0````````````(`MP`!````8"-```````!``````````'BC````
M`````````$``.``(`$``&P`:``8````%````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````;`````````!L``````````0`````````!````
M!0````````````````!``````````$```````.28````````Y)@`````````
M``$```````$````&````P)T```````#`G4$``````,"=00``````<`0`````
M``#(%````````````0```````@````8```#8G0```````-B=00``````V)U!
M`````````@`````````"````````"``````````$````!````!P"````````
M'`)````````<`D```````$0`````````1``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0```#`G0```````,"=00``````P)U!``````!``@``````
M`$`"`````````0`````````O;&EB+VQD+6QI;G5X+6%A<F-H-C0N<V\N,0``
M!````!`````!````1TY5```````#````!P`````````$````%`````,```!'
M3E4`J3]A0KZ^CF%Q;/_!':2K4*B(MFAA````!0```!`````*````H!``*`)&
M$0```&``5@)0&(((`"!(`!`1``@0`@`@`````````$@"(`X`"@``A`*H00`%
M(&@(A$DX0A25!D$H"BA8B($%8`26"`E"2G!``!@!`4!""`!`@(S`!``($)`0
M`P$`"($8@(%`0(*9@"Q`"`(!!"``8``)!)$C!(J74&`%``````````8````'
M````"0`````````````````````````*````#`````T````/````$````!$`
M```3````%@`````````````````````````8````&P```!P`````````(```
M`"$````B`````````",````D````*``````````J```````````````K````
M+````"T````N`````````#(````S`````````#<``````````````#@````[
M````/``````````]````/@```$````!"````10````````!'````2````$D`
M``!*`````````$L```````````````````````````````````!,````30``
M``````!/`````````%$```!3````50````````````````````````!6````
M6@````````!<`````````%T`````````7P```&```````````````&(```!C
M````90```&8```!I````7Y:3'*-:[Y#"CH?_5]N3'`TZEPO2402$@72"#7OP
M2FMV5#R4S3\,K_<CSB")!W#3('2P`M5DU'QFK\QF+DX]]MOW`%X&I(?_`:\T
MZ,[>1RW@IP(*STJN_^-'Q@$^?I9\Q@[@/>P_D`)M<X7%Q8D%D&&8[Q(!(_FD
MG;N3'$)%U>Q\[1$/4.X1XX?YG(%:FCL/NY63'$%-G7RGW:-K6>^7>3GRBQP,
M%.*>!#*EA:("]AG;S>.>^Z%L8.K3[P[(.4`?,F+;[;F-\0[I^\/"[-Z3'$HB
M??\+BA!7K4OCP-EQ6!PKT.$B&I_6O2T.L7-8.T`?P^4_+)@BU&BZXY)\(?_D
M#HJ8W<)O>FGZDZT$8C?C\,%#\N_(WX4@3U>DFY;%N9Q`4!M]7S&X@@V^VE<;
MLP&+;W9OXW"]T$M]GB+'J&L)0]8A8F0'?JF<FV+0^H+L+/:+:W^:?-"?+/R'
M\)9\[PM1^9!U@@U#9DL0!6RRS3RM.0T7ZEKQH^#[2>)7Q!A7DEI2_=+O#V[%
MWQ]\D!#I+=_^2"[%F[;)U;)Q````````````````````````````````````
M`!$````@`````````````````````````"T````@````````````````````
M`````#P````@`````````````````````````%`````@````````````````
M`````````$,#```2``````````````````````````8"```2````````````
M`````````````($"```2`````````````````````````)T"```2````````
M`````````````````#@$```@`!<`$*)!`````````````````)L!```2````
M`````````````````````'H"```2`````````````````````````(L!```2
M````X!U``````````````````*$#```0`!@`,*)!`````````````````#0"
M```2`````````````````````````%\"```2````````````````````````
M`'@$```1`!<`**)!```````(`````````.`"```2````````````````````
M`````,0$```2``T`$%%```````#P`P```````!T$```2``T`$$%````````X
M`0```````$H#```2`````````````````````````$4"```2````````````
M`````````````/$"```2`````````````````````````+`#```0`!@`B+)!
M`````````````````"D$```2``T`*$9```````#D"@```````%($```2``T`
MV#U````````$`0```````/L#```2`````````````````````````!`$```2
M``T`\$!````````@`````````"\"```2`````````````````````````&P"
M```2`````````````````````````&0!```2````````````````````````
M`,T"```2`````````````````````````%T#```A`!@`4*)!```````(````
M`````.X!```2`````````````````````````/4!```2````````````````
M`````````(\"```2`````````````````````````(X#```0`!<`,*)!````
M`````````````'0"```2`````````````````````````*H"```2````````
M`````````````````(<````2````L"!``````````````````.@!```2````
M`````````````````````!4#```2``````````````````````````X"```2
M`````````````````````````%X#```A`!@`4*)!```````(`````````+L#
M```0`!@`B+)!`````````````````.H"```1`!@`,*)!```````(````````
M`,@#```2``T`%%9````````$`````````&\!```2````````````````````
M`````$L!```2`````````````````````````&@$```2``T`G%5```````!X
M`````````*0$```2``T`Z$1````````\`0```````-(#```2``X`&%9`````
M`````````````$X"```2`````````````````````````#P$```2``T`8"-`
M`````````````````)$$```2``L`^!Q``````````````````*<````2````
M`````````````````````(@"```2`````````````````````````+\"```2
M`````````````````````````.L````1`!@`0*)!```````!`````````$,$
M```1``\`*%9````````$`````````)4#```0`!@`,*)!````````````````
M`!P#```2`````````````````````````#0#```2````````````````````
M`````&H````2`````````````````````````/@````2````````````````
M`````````(\$```2``T`4#U````````T`````````!0!```2````````````
M`````````````,,#```0`!@`B+)!`````````````````)<$```2``T`Z#Y`
M```````(`@```````+P````2`````````````````````````!T"```2````
M`````````````````````-0!```2`````````````````````````'T!```2
M`````````````````````````,H````2`````````````````````````-P`
M```2``````````````````````````D!```1`!@`.*)!```````$````````
M`%P#```1`!@`4*)!```````(`````````#T!```2````````````````````
M`````)8"```2`````````````````````````*\#```0`!@`B+)!````````
M`````````+8$```2``T`*$1```````"8`````````-@"```2````````````
M`````````````)@````2`````````````````````````"8#```2````````
M`````````````````#8$```0`!<`$*)!`````````````````'P#```1`!@`
M2*)!```````(`````````.D#```2``T`P$1````````H`````````+D!```2
M`````````````````````````*8!```2`````````````````````````%<#
M```2``T`4"%````````0`@````````$#```2````````````````````````
M`!D!```2`````````````````````````/@"```2````````````````````
M`````+@"```2`````````````````````````*0"```2````````````````
M`````````#P"```2`````````````````````````+(!```2````````````
M`````````````#P#```2`````````````````````````(($```2``T`2$)`
M``````#<`0````````@#```2`````````````````````````!X!```2````
M`````````````````````&8"```2``````````````````````````0$```2
M``T``%5```````"``````````'@````2`````````````````````````%L!
M```2`````````````````````````-@#```2``T`X#Y````````$````````
M`"H!```2````("!```````````````````!L:6)P97)L+G-O+C4N,C(`7TE4
M35]D97)E9VES=&5R5$U#;&]N951A8FQE`%]?9VUO;E]S=&%R=%]?`%]*=E]2
M96=I<W1E<D-L87-S97,`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!097)L
M7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?871F;W)K7VQO8VL`<&5R
M;%]C;VYS=')U8W0`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]A=E]S:&EF
M=`!097)L7W-V7S)P=E]F;&%G<P!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U
M;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`'!E<FQ?9G)E90!097)L
M7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L
M7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T
M`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R
M;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`;&EB<'1H<F5A9"YS;RXP`'!T
M:')E861?9V5T<W!E8VEF:6,`8VQO<V4`;W!E;C8T`%]?97)R;F]?;&]C871I
M;VX`;'-E96LV-`!R96%D`&QI8F,N<V\N-@!?7W)E9VES=&5R7V%T9F]R:P!E
M>&ET`'-T<FYC;7``7U]S=')D=7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I
M;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!A8F]R=`!M96UC:'(`9V5T<&ED`'-T
M<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK
M`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS
M=&%T-C0`<W1D97)R`&=E='5I9`!R96%D;&EN:P!E>&5C=G``7U]M96UC<'E?
M8VAK`'-T<F-H<@!R96%D9&ER-C0`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C
M8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`&QD+6QI
M;G5X+6%A<F-H-C0N<V\N,0!?7W-T86-K7V-H:U]G=6%R9`!?961A=&$`7U]B
M<W-?<W1A<G0`7U]B<W-?<W1A<G1?7P!?7V)S<U]E;F1?7P!?7V5N9%]?`%]E
M;F0`7U]L:6)C7V-S=5]F:6YI`'!A<E]C=7)R96YT7V5X96,`9V5T7W5S97)N
M86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``<&%R7V)A<V5N86UE`'!A
M<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!?7V1A=&%?<W1A<G0`7TE/7W-T9&EN
M7W5S960`<&%R7V-U<G)E;G1?97AE8U]P<F]C`%]?;&EB8U]C<W5?:6YI=`!M
M>5]P87)?<&P`<&%R7VEN:71?96YV`'AS7VEN:70`<&%R7V9I;F1P<F]G`'!A
M<E]S971U<%]L:6)P871H`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!
M4E]"3T]4`$=,24)#7S(N,3<````````````````"``,``@`"``$````"````
M`0`"``(``0`"``$``0`"``(``@`!``$``0`"``$``@`"`````@`"``,``P`"
M``$``@`"`````P`"``,``@`!``(``0```````0`!``$``@`!``$````"``(`
M```!``$``@`"```````!`````0`!`````@`#`````````````@````(``0`!
M``(````"``$`!``!```````!``(``@`"``(``@`"``(``@`!``(````"``$`
M``````$``````````0`!`&8#```0````(````)>1E@8```0`V@0````````!
M``$`Q`$``!`````@````EY&6!@```P#:!`````````$``0`3`@``$```````
M``"7D98&```"`-H$````````X)]!```````!!````@``````````````,*)!
M````````!```+0``````````````.*)!````````!```2P``````````````
M0*)!````````!```.@``````````````2*)!````````!```50``````````
M````4*)!````````!```3````````````````*!!```````"!```70``````
M````````"*!!```````"!```/@``````````````$*!!```````"!```.```
M````````````&*!!```````"!```(P``````````````(*!!```````"!```
M4P``````````````**!!```````"!```'```````````````,*!!```````"
M!```$0``````````````.*!!```````"!```7```````````````0*!!````
M```"!```%@``````````````2*!!```````"!```40``````````````4*!!
M```````"!```10``````````````6*!!```````"!```#```````````````
M8*!!```````"!```1@``````````````:*!!```````"!```7P``````````
M````<*!!```````"!```4@``````````````>*!!```````"!```0@``````
M````````@*!!```````"!```8P``````````````B*!!```````"!```!P``
M````````````D*!!```````"!```8```````````````F*!!```````"!```
M.0``````````````H*!!```````"!```+P``````````````J*!!```````"
M!```30``````````````L*!!```````"!```#@``````````````N*!!````
M```"!```%```````````````P*!!```````"!```3@``````````````R*!!
M```````"!```20``````````````T*!!```````"!```5P``````````````
MV*!!```````"!```!@``````````````X*!!```````"!```6```````````
M````Z*!!```````"!```1P``````````````\*!!```````"!```'0``````
M````````^*!!```````"!```%0```````````````*%!```````"!```-```
M````````````"*%!```````"!```*```````````````$*%!```````"!```
M,```````````````&*%!```````"!````@``````````````(*%!```````"
M!```)0``````````````**%!```````"!```80``````````````,*%!````
M```"!```9P``````````````.*%!```````"!```6@``````````````0*%!
M```````"!```)@``````````````2*%!```````"!```!0``````````````
M4*%!```````"!```&@``````````````6*%!```````"!```7@``````````
M````8*%!```````"!```-P``````````````:*%!```````"!```'@``````
M````````<*%!```````"!```'P``````````````>*%!```````"!```:@``
M````````````@*%!```````"!```6P``````````````B*%!```````"!```
M/P``````````````D*%!```````"!```/0``````````````F*%!```````"
M!```9```````````````H*%!```````"!```"@``````````````J*%!````
M```"!```0```````````````L*%!```````"!```*0``````````````N*%!
M```````"!```2```````````````P*%!```````"!```)P``````````````
MR*%!```````"!```*@``````````````T*%!```````"!```"P``````````
M````V*%!```````"!```(0``````````````X*%!```````"!```2@``````
M````````Z*%!```````"!```:```````````````\*%!```````"!```"```
M````````````^*%!```````"!```(@```````````````*)!```````"!```
M#P``````````````"*)!```````"!```90``````````````_7N_J?T#`)&J
M`0"4_7O!J,`#7]8`````\'N_J=```)`1_D?Y$.(_D2`"']8?(`/5'R`#U1\@
M`]70``"P$0)`^1`"`)$@`A_6T```L!$&0/D0(@"1(`(?UM```+`1"D#Y$$(`
MD2`"'];0``"P$0Y`^1!B`)$@`A_6T```L!$20/D0@@"1(`(?UM```+`1%D#Y
M$*(`D2`"'];0``"P$1I`^1#"`)$@`A_6T```L!$>0/D0X@"1(`(?UM```+`1
M(D#Y$`(!D2`"'];0``"P$29`^1`B`9$@`A_6T```L!$J0/D00@&1(`(?UM``
M`+`1+D#Y$&(!D2`"'];0``"P$3)`^1""`9$@`A_6T```L!$V0/D0H@&1(`(?
MUM```+`1.D#Y$,(!D2`"'];0``"P$3Y`^1#B`9$@`A_6T```L!%"0/D0`@*1
M(`(?UM```+`11D#Y$"("D2`"'];0``"P$4I`^1!"`I$@`A_6T```L!%.0/D0
M8@*1(`(?UM```+`14D#Y$(("D2`"'];0``"P$59`^1"B`I$@`A_6T```L!%:
M0/D0P@*1(`(?UM```+`17D#Y$.("D2`"'];0``"P$6)`^1`"`Y$@`A_6T```
ML!%F0/D0(@.1(`(?UM```+`1:D#Y$$(#D2`"'];0``"P$6Y`^1!B`Y$@`A_6
MT```L!%R0/D0@@.1(`(?UM```+`1=D#Y$*(#D2`"'];0``"P$7I`^1#"`Y$@
M`A_6T```L!%^0/D0X@.1(`(?UM```+`1@D#Y$`($D2`"'];0``"P$89`^1`B
M!)$@`A_6T```L!&*0/D00@21(`(?UM```+`1CD#Y$&($D2`"'];0``"P$9)`
M^1""!)$@`A_6T```L!&60/D0H@21(`(?UM```+`1FD#Y$,($D2`"'];0``"P
M$9Y`^1#B!)$@`A_6T```L!&B0/D0`@61(`(?UM```+`1ID#Y$"(%D2`"'];0
M``"P$:I`^1!"!9$@`A_6T```L!&N0/D08@61(`(?UM```+`1LD#Y$((%D2`"
M'];0``"0$;9`^1"B!9$@`A_6T```D!&Z0/D0P@61(`(?UM```)`1OD#Y$.(%
MD2`"'];0``"0$<)`^1`"!I$@`A_6T```D!'&0/D0(@:1(`(?UM```)`1RD#Y
M$$(&D2`"'];0``"0$<Y`^1!B!I$@`A_6T```D!'20/D0@@:1(`(?UM```)`1
MUD#Y$*(&D2`"'];0``"0$=I`^1#"!I$@`A_6T```D!'>0/D0X@:1(`(?UM``
M`)`1XD#Y$`('D2`"'];0``"0$>9`^1`B!Y$@`A_6T```D!'J0/D00@>1(`(?
MUM```)`1[D#Y$&('D2`"'];0``"0$?)`^1""!Y$@`A_6T```D!'V0/D0H@>1
M(`(?UM```)`1^D#Y$,('D2`"'];0``"0$?Y`^1#B!Y$@`A_6T```D!$"0?D0
M`@B1(`(?UM```)`1!D'Y$"((D2`"'];]>[JI_0,`D?-3`:G4``"0]5L"J8,B
M"9&BAP.IH0,!D60`0/FD+P#Y!`"`TJ!/`+FBXP"1H#,!D=,``+#5``"0@/__
MEP(``)````"00H``D0#``I'A`P*J]@P`E,```)```$DY0`$`-4;__Y=B@@V1
M0``2^*`,`+35``"0$?__EZ`Z0KE+__^7'U0D.:`Z0KE(__^7X@,`JJ`Z0KE!
M2%0Y(0`?,D%(%#E"__^7`4A4.2$``#(!2!0YH$]`N0`4`!$`?'V3-___EZ0C
M0/G&``"088(-D:)/0+D%``#P`P``\,<40?F(`(!2A@!`^:4@*I%C0"J17P0`
M<084`*D'#`&I*(`0N"``$?BM!@!4A"``D4,0`!&A`(!2YP"`DN7,(8N&A$#X
M(00`$3\``VL&:"7X8?__5':"#9$%S".+`0``L.,#`*I"#``1(2`VD<`"4O@$
M`(#2OX`?^'+__Y?U`P`JX`(`-':"#9'``E+X[?[_EP```/"A4P&1`*`?D?4$
M`)1@`@"T<X(-D90B"9%@`E+XT/[_EU?__Y>B+T#Y@0)`^4$``<K@`Q4JX0(`
MM?-30:GU6T*I_7O&J,`#7];``E+X?/__E_4#`"KG__\7P()1^*```+1W#`"4
MZ___%T,`"`O5__\7````\*%3`9$`P!V1V`0`E,""$?A@_/^T;0P`E.'__Q?W
M_O^7(`"`4HG^_Y<=`(#2'@"`TN4#`*KA`T#YXB,`D>8#`)'```!8XP``6`0!
M`%C'_O^7^O[_EP````!0(4```````)Q50```````%%9```````"@``#P`/!'
M^4```+3K_O\7P`-?U@````#!``"0P```D"'`")$`P`B1(1P`D2$``,L_.`#Q
MJ0``5`$``)`A_$'Y00``M"``'];``U_6'R`#U0``````````P0``D,```)`A
MP`B1`,`(D2$``,LA_$.3(?Q!BR'\09/!``"T`@``D$(@0OEB``"T0``?UA\@
M`]7``U_6'R`#U0``````````_7N^J?T#`)'S"P#YTP``D&!B23F````UV/__
MER``@%)@8@DY\PM`^?U[PJC``U_6H```\`!`-Y$!`$#Y80``M=[__Q<?(`/5
M`0``D"%80OF!__^T_7N_J?T#`)$@`#_6_7O!J-7__Q<``````````/]#"M'(
M``"0`2$)D0;@`)$)X`&1_7N_J?T#`)$B`$#YHD\!^0(`@-*B8P"1Y0,"JL,`
M0+FE0`"1P81`^&,(P%JC`!_XWP`)ZR3\8-,G_&C3@]QXT^<<>)*$'&C38QQP
MDN'@0:J#``.J80`!JJ&`'_@!_O]4IF,(D4,`0/E"(`"1101`^4$<0/E$,$#Y
MHP`#RE\`!NN!``'*80`!RB/\7]-A!`&J(7Q`DD$\`/EA_O]4!RQ`J2$SC]()
M*$&I8`%GGB(!9Y[C_%O300%GG@P00/FBET&I8Q0'JF;]0M-!4*OR(P%GG@@A
M"9&"`0*+QG@+JD`<82["`&>>S7Q`DD4!!8NF%T#Y)@$&BP0`9IZ#0".+Y/Q"
MTV(``HM"``&+A'@'JH$`9YY#?$"20`!GGB`<8BZB`6>>`@!FGN``9YY`'&,N
M(D`BBT8`!HL$`&:>A``!BX4`!8MD_%O3A!0#JJ1`)(ME_$+3@@!GGH)\0)*C
M>`.J)`!FGF``9YZ%?$"21/Q;TP(<82Z$%`*JQ$`DBZ8;0/E#`&:>@@!GGL8`
M`8NC02.+3?Q"TV8`!HN#?$"2HGD"J@0`9IY!`&>>;?Q"TX1\0)(B'&`N0@!F
MGJ)`(HME_%O3I10#JJ-Y`ZI@`&>>Q4`EBZ8?0/FB`&>>Q@`!BT8`!HNB?$"2
M1?Q;TTW\0M,"'&$NI10"JJ)Y`JK%0"6+IB-`^4,`9IZB`&>>Q@`!BX-`(XLD
M`&:>00!GGF8`!HNC?$"29?Q;TVW\0M.$?$"2(AQ@+J44`ZJC>0.JQ4`EBZ8G
M0/G&``&+0@!FGJ(`9YZ"0"*+!`!FGF``9YY&``:+HGQ`DD7\6]--_$+3A'Q`
MD@(<82ZE%`*JHGD"JL5`)8NF*T#YQ@`!BT,`9IZB`&>>@T`CBR0`9IY!`&>>
M9@`&BZ-\0))E_%O3;?Q"TX1\0)(B'&`NI10#JJ-Y`ZK%0"6+IB]`^<8``8M"
M`&:>H@!GGH)`(HL$`&:>8`!GGD8`!HNB?$"21?Q;TTW\0M.$?$"2`AQA+J44
M`JJB>0*JQ4`EBZ8S0/G&``&+0P!FGJ(`9YZ#0".+)`!FGD$`9YYF``:+HWQ`
MDF7\6]-M_$+3A'Q`DB(<8"ZE%`.JHWD#JL5`)8NF-T#YQ@`!BT(`9IZB`&>>
M@D`BBP0`9IY@`&>>1@`&BZ)\0))%_%O33?Q"TX1\0)("'&$NI10"JJ)Y`JK%
M0"6+ICM`^<8``8M#`&:>H@!GGH-`(XLD`&:>00!GGF8`!HNC?$"29?Q;TVW\
M0M.$?$"2(AQ@+J44`ZJC>0.JQ4`EBZ8_0/G&``&+0@!FGJ(`9YZ"0"*+!`!F
MGF``9YY&``:+HGQ`DD7\6]--_$+3A'Q`D@(<82ZE%`*JHGD"JL5`)8NF0T#Y
MQ@`!BT,`9IZB`&>>@T`CBR0`9IY!`&>>9@`&BZ-\0))E_%O3;?Q"TX1\0)(B
M'&`NI10#JJ-Y`ZK%0"6+ID=`^<8``8M"`&:>H@!GGH)`(HL$`&:>8`!GGD8`
M!HNB?$"21?Q;TTW\0M.$?$"2`AQA+J44`JJB>0*JQ4`EBZ9+0/G&``&+0P!F
MGJ(`9YZ#0".+)`!FGD$`9YYF``:+HWQ`DF7\6]-M_$+3A'Q`DB(<8"ZE%`.J
MHWD#JL5`)8NF3T#YQ@`!BT(`9IZB`&>>@D`BBP0`9IY@`&>>1@`&BZ)\0)(C
M`&:>A'Q`D@(<82YC?$"210!FGH5`)8M$_%O3A!0"JL1`)(NF4T#Y@0!GGHU\
M0)+&``&+I@`&BT7\0M.B>`*J0@!GGD$<8"XD`&:>94`DBZ3]6],#`&:>A!0-
MJL1`)(NF5T#Y@`!GGH]\0)+&``&+I@`&BZ7]0M-C?$"2I7@-JJ$`9YX@'&(N
M!`!FGF-`)(OD_5O3A!0/JL1`)(NF6T#YCGQ`DL$``8NF7T#Y80`!B^/]0M-O
M>`^JP_U;TV,4#JHC0".+H0`/RFU\0)(D``1*(72=TB';K?*"0"*+Q@`!B\3]
M0M-&``:+HOU;TX1X#JI"%`VJPD`BB^8!!,K#``-*3GQ`DF5`)8NC8T#Y8P`!
MBZ4``XO#_5O38Q0.JJ-`(XNE_4+39GQ`DJUX#:J%``W*H@`"2D5`+XNB9T#Y
M0@`!BZ4``HO"_%O30A0&JJ)`(HO%_4+3KG@.JD5\0)*O`0[*XP$#2F1`)(NC
M:T#Y8P`!BX0``XNC_%O38Q0%JH-`(XO$_$+3AG@&JF1\0)+/`0;*X@$"2DU`
M+8NB;T#Y0@`!BZT!`HN"_%O30A0$JJ)!(HNM_$+3I7D%JDU\0)+/``7*XP$#
M2FY`+HNC<T#Y8P`!B\X!`XNC_5O38Q0-JL-!(XN._$+3Q'D$JFY\0)*O``3*
MX@$"2D9`)HNB=T#Y0@`!B\8``HO"_5O30A0.JL)`(HNF_4+3S7@-JD9\0)*/
M``W*XP$#2F5`)8NC>T#Y8P`!BZ4``XO#_%O38Q0&JJ-`(XO%_4+3KG@.JF5\
M0)*O`0[*X@$"2D1`)(NB?T#Y0@`!BX0``HNB_%O30A0%JH)`(HO$_$+3AG@&
MJD1\0)+/`0;*XP$#2FU`+8NC@T#Y8P`!BZT!`XN#_%O38Q0$JJ-!(XNM_$+3
MI7D%JFU\0)+/``7*X@$"2DY`+HNBAT#Y0@`!B\X!`HNB_5O30A0-JL)!(HN.
M_$+3Q'D$JDY\0)*O``3*XP$#2F9`)HNCBT#Y8P`!B\8``XO#_5O38Q0.JL-`
M(XNF_4+3S7@-JF9\0)*/``W*X@$"2D5`)8NBCT#Y0@`!BZ4``HO"_%O30A0&
MJJ)`(HO%_4+3KG@.JD5\0)*O`0[*XP$#2F1`)(NCDT#Y8P`!BX0``XNC_%O3
M8Q0%JH-`(XO$_$+3AG@&JF1\0)+/`0;*X@$"2DU`+8NBET#Y0@`!BZT!`HN"
M_%O30A0$JJ)!(HNM_$+3I7D%JDU\0)+/``7*XP$#2FY`+HNCFT#Y8P`!B\X!
M`XNC_5O38Q0-JL-!(XN._$+3Q'D$JFY\0)*O``3*X@$"2D9`)HNBGT#Y0@`!
MB\8``HO"_5O30A0.JL)`(HNF_4+3S7@-JD9\0)*/``W*XP$#2F5`)8NCHT#Y
M8P`!BZ4``XO#_%O38Q0&JJ-`(XO%_4+3KG@.JF5\0)*O`0[*X@$"2L_\0M/O
M>0:J1$`DB\8!#\K#``-*HIM4J6-`+8M"``&+P0`!BX0``HNB_%O380`!BT(4
M!:J"0"*+1'Q`DH;\6]/&%`2J)D`FBZ'\0M/#?$"2)7@%JN$!!:HB``**X0$%
MBD(``2J!FY?28>.Q\DY`+HNBKT#Y0@`!B\(!`HMN_%O3SA4#JDY`+HN"_$+3
M1'@$JL)]0)*M``2JI@$&BJT`!(K&``TJK;-`^<9`+XNM`0&+Q@`-BTW\6].M
M%0*JS4`MBV;\0M/#>`.JIGU`DH\``ZKN`0Z*CP`#BLX!#RK%026+KK=`^<X!
M`8NE``Z+SOQ;T\X5!JJN0"Z+1?Q"TZ)X`JK%?4"2;P`"JNT!#8IO``**K0$/
M*J1!)(NMNT#YK0$!BX0`#8NM_%O3K14%JHU`+8O$_$+3AG@&JJ1]0))/``:J
M[@$.BD\`!HK.`0\JPT$CBZZ_0/G.`0&+8P`.BX[\6]/.%02J;D`NBZ/\0M-E
M>`6JPWU`DL\`!:KM`0V*SP`%BJT!#RJB02*+K<-`^:T!`8M"``V+;?Q;TZT5
M`ZI-0"V+@OQ"TT1X!*JB?4"2KP`$JNX!#HJO``2*S@$/*L9!)HNNQT#YS@$!
MB\8`#HM._%O3SA4"JLY`+HMF_$+3PW@#JL9]0)*/``.J[0$-BH\``XJM`0\J
MI4$EBZW+0/FM`0&+I0`-B\W\6].M%0:JK4`MBT7\0M.B>`*JI7U`DF\``JKN
M`0Z*;P`"BLX!#RK$022+KL]`^<X!`8N$``Z+KOQ;T\X5!:J.0"Z+Q/Q"TX9X
M!JK$?4"23P`&JNT!#8I/``:*K0$/*J-!(XNMTT#YK0$!BV,`#8N-_%O3K14$
MJFU`+8NC_$+397@%JJ-]0)+/``6J[@$.BL\`!8K.`0\JPD$BBZ[70/G.`0&+
M0@`.BV[\6]/.%0.J3D`NBX+\0M-$>`2JPGU`DJ\`!*KM`0V*KP`$BJT!#RJF
M02:+K=M`^:T!`8O&``V+3?Q;TZT5`JK-0"V+9OQ"T\-X`ZJF?4"2CP`#JNX!
M#HJ/``.*S@$/*L5!)8NNWT#YS@$!BZ4`#HO._%O3SA4&JJY`+HM%_$+3HG@"
MJL5]0))O``*J[0$-BF\``HJM`0\JI$$DBZWC0/FM`0&+A``-BZW\6].M%06J
MC4`MB\3\0M.&>`:JI'U`DD\`!JKN`0Z*3P`&BLX!#RK#02.+KN=`^<X!`8MC
M``Z+COQ;T\X5!*IN0"Z+H_Q"TV5X!:K#?4"2SP`%JNT!#8K/``6*K0$/*J)!
M(HNMZT#YK0$!BT(`#8MM_%O3K14#JDU`+8N"_$+31'@$JJ)]0)*O``2J[@$.
MBJ\`!(K.`0\JQD$FBZ[O0/G.`0&+Q@`.BT[\6]/.%0*JQD`NBV[\0M//?$"2
MPWD#JHX``ZK-`0V*C@`#BJT!#BJE026+K?-`^:T!`8NE``V+[?U;TZT5#ZJE
M0"V+3?Q"TZ)Y`JJM?$"2;@`"JL8!!HIN``**Q@`.*J[W0/G$0"2+S@$!BX0`
M#HNN_5O3YOU"T\X5#:K&>`^JA$`NBTX`!JK%`06*3@`&BJ4`#BJ/?$"2HT`C
MBZ7[0/FA``&+80`!B^/]6]-C%`^J(T`CBZ']0M-E?$"2+7@-JL$`#<HD``1*
MP3J8TD%,N?*"0"*+I/]`^80``8M$``2+HOQ;TT(4!:J"0"*+Y/U"TX]X#ZI$
M?$"2K@$/RL,!`TIC0":+I@-!^<8``8MF``:+@_Q;TV,4!*K#0".+IOQ"TVY\
M0)+%>`6JY@$%RL(``DI&0"V+H@=!^4(``8O&``*+POU;TT(4#JK"0"*+AOQ"
MTTU\0)+$>`2JI@`$RL,``TIF0"^+HPM!^6,``8O&``.+H_U;TV,4#:K#0".+
MQOU"T\YX#JIF?$"2CP`.RN(!`DI%0"6+H@]!^4(``8NE``*+POQ;TT(4!JJB
M0"*+I?U"TZUX#:I%?$"2SP$-RN,!`TID0"2+HQ-!^6,``8N$``.+H_Q;TV,4
M!:J#0".+Q/Q"TX9X!JID?$"2KP$&RN(!`DI.0"Z+HA=!^4(``8O.`0*+@OQ;
MTT(4!*K"02*+KOQ"T\5Y!:I.?$"2SP`%RN,!`TIM0"V+HQM!^6,``8NM`0.+
MP_U;TV,4#JJC02.+C?Q"TZ1Y!*IM?$"2KP`$RN(!`DI&0":+HA]!^4(``8O&
M``*+HOU;TT(4#:K"0"*+QOU"T\YX#JI&?$"2CP`.RN,!`TIE0"6+HR-!^6,`
M`8NE``.+P_Q;TV,4!JJC0".+I?U"TZUX#:IE?$"2SP$-RN(!`DI$0"2+HB=!
M^4(``8N$``*+HOQ;TT(4!:J"0"*+Q/Q"TX9X!JI$?$"2KP$&RN,!`TIN0"Z+
MHRM!^6,``8O.`0.+@_Q;TV,4!*K#02.+KOQ"T\5Y!:IN?$"2SP`%RN(!`DI-
M0"V+HB]!^4(``8NM`0*+POU;TT(4#JJB02*+C?Q"TZ1Y!*I-?$"2KP`$RN,!
M`TIF0":+HS-!^6,``8O&``.+H_U;TV,4#:K#0".+QOU"TV]\0)+.>`ZJA@`.
MRL(``DI%0"6+HC=!^4(``8NE``*+XOU;TT(4#ZJB0"*+I?U"TT9\0)*M>`VJ
MQ0$-RJ,``TID0"2+HSM!^6,``8N#``.+Q/Q;TX04!JID0"2+X_U"TV]X#ZJ#
M?$"2I0$/RJ(``DJE/T'Y0D`NBZ4``8M%``6+8OQ;TT(4`ZJB0"*+Q?Q"TZ9X
M!JI%?$"2[@$&RL0!!$J-0"V+I$-!^80``8ND`02+K?Q;TZT5!:J$0"V+;?Q"
MTZ-Y`ZJ-?$"2;``,"PP0`/G,``/*@@$"2DQ`+XNB1T'Y0@`!BX(!`HNL_5O3
MC!4-JH(!`@MK`0(+"P0`^:O\0M-E>06J8P`%RJ4`"@MC``1*I$M!^04,`/EF
M0":+0_Q;TX$``8MB%`*JP0`!BT$``0LA``<+`0``^:%/0?D"`4#Y(@`"RJ']
M0M,A>`VJ*0`)"PD(`/F"``"U_7O!J/]#"I'``U_6)?K_EP`'`+3]>[RIH@``
M\/T#`)'W8P.I6"A!^?-3`:GU6P*I&`,`M`,`0#FB!X!2%`"`4G\`'VMD$$)Z
MXP>?&N,"`#43`T#Y\P$`M/<#`:KV`P"JE'Y`D_4#&*K@`Q.JX@,4JN$#%JKC
M^?^7@```-6!J=#@?]`!Q(`(`5+..0/CS_O^U``"`TO-30:GU6T*I]V-#J?U[
MQ*C``U_6]`,`JH,>0#A_`!]K9!!">J'__U24`@!+Y/__%Q\@`]6B`AC+@`8`
MD6`"`(M"_$.3X@(`N?-30:GU6T*I]V-#J?U[Q*C``U_6``"`TL`#7];]>[RI
M_0,`D?-3`:GS`P"J]1,`^;4``/"@(@F1M```\`$`0/FA'P#Y`0"`TJ'3`)'@
M`Q.JN?__E^`!`+2"*D'YHS>`N4`,`XL!!$#Y07@C^.'^_[0`(`"1`01`^0$`
M`/FA__^UH=,`D>`#$ZJK__^78/[_M;4B"9&A'T#YH`)`^2```,J@``"U\U-!
MJ?430/G]>\2HP`-?UL3Y_Y<?(`/5_7NYJ?T#`)'S4P&I\P,!JO5;`JGT`P"J
M]V,#J;4``/#Y:P2IH2()D?LK`/E@`D`Y(@!`^:(W`/D"`(#2'_0`<7,6DYK@
M`Q.J//G_E_<#`*JADP&1X`,4JHC__Y<@"`"T]@,`JC7Y_Y<?0#?KX@8`5+9G
M0+FX``#P@`)`.:('@%(?`!]K!!!">L`+`%3A`Q2J(!Q`.!\`'VL$$$)ZH?__
M5"$`%$O@"@`1%RM!^0```0OV`Q8J7?G_E^!Z-OC`"@"T`BM!^:,'@%*D9T"Y
M@`8`D8$"0#D_`!]K0GAD^"000WI!```YP```5`$40#@_`!]K01P`."000WJ!
M__]4H`>`4D$$`)%````Y8!9`."`4`#C`__\U``"`4K4B"9&B-T#YH0)`^4$`
M`<JA!P"U\U-!J?5;0JGW8T.I^6M$J?LK0/G]>\>HP`-?U@``@-)A:F`XP6H@
M.``$`)&A__\U[O__%[@``/`:*T'Y0`-`^>`$`+3A`QJJ``"`4@,``!0?(`/5
MX`,6*B*,0/@6!``1HO__M0`,`!$`?'V3H0``\")@0KF"`0`TX0,`JN`#&JI/
M^?^7`"L!^0`#`+39?D"3.0<`D1]X.?BV9P"YK/__%Q\@`]4B`(!2(F`"N13Y
M_Y?[`P"JH`$`M-E^0)/A`QJJ(O-]T\KX_Y<;*P'YX`,;JO#__Q<!`(!2J/__
M%P`"@-(6`(!2XO__%P``@!+`__\7._G_E_U[LZG]`P"1\U,!J;0``/#U6P*I
M@2()D?=C`ZDB`$#YHF<`^0(`@-*```"T`0!`.?4#`*IA`0`UE"()D:%G0/F`
M`D#Y(```RJ`(`+7S4T&I]5M"J?=C0ZG]>\VHP`-?UL;X_Y?V`P"J@/[_M!@`
M`-`8`QR1X`,6JF3Y_Y?E`P"JX`0`M*!,0#D?N`!Q(`4`5.`#%:JS3`"1H/C_
ME_<#`*K@`Q.JG?C_EP``%PL`"``1`'Q`D]7X_Y?W`P"JY0,3JN0#%:KC`QBJ
M`@"`DB$`@%*6^/^7HB,!D>$#%ZH``(!2FOC_EQ\$`#&@``!4H%M`N0`,%!(?
M$$!QP`(`5.`#%ZIZ^?^7X`,7JCCY_Y?@`Q:J/OG_E^4#`*I@^_^UX`,6JN[X
M_Y?@`Q6J'/G_E\/__Q>@4$`Y`/K_-!^X`'&A^O]4H%1`.8#Y_S32__\7'R`#
MU>`#%ZJK__^7Z___%^/X_Y?]>[ZI_0,`D?-3`:FS``#P]`,`JF`Z0KG0^/^7
M`N`'D>$#%*H``(!2$/G_EZ```#0``(!2\U-!J?U[PJC``U_68#I"N<7X_Y<`
M"$*Y``P4$A\00''@``!48#I"N;_X_Y<`"$*Y``P4$A\H0'$A_O]4X`,4JD$`
M@%+8^/^7'P`?:^`7GQKS4T&I_7O"J,`#7];_!T#1`P``T/^#`-'B`(*2_7N]
MJ?T#`)'U6P*I]0,`JO-3`:E@(!R1]@,!JJ-#`)$!"(+2LP``\"$``XMC(@F1
M(0`"BV0`0/FD)PCY!`"`TN+_@=)%^/^7'P`?:\T$`%0"!`!1H<,^T51\0),A
M`!2+(>!_.>$#`#04?$"3`0B"TJ-#`)$A``.+X`""DB```(OB`Q2JX06`4J`?
M`/G_^/^7H`(`M*```/``.$*YA_C_EZ(?0/GC`Q2JX0,5JO_X_Y=S(@F1H2=(
M^6`"0/D@``#*``(`M?-30:GU6T*I_7O#J/\'0)'_@P"1P`-?UA\@`]5B_/\U
MH```\``X0KES^/^7X@,6JN$#%:I0^/^7[?__%WKX_Y<?(`/5H```\/U[OZG]
M`P"1`#A"N6CX_Y<#``#0XO__T`$``-!CP!B1_7O!J$*`-Y$A8!R1H/C_%Q\@
M`]7]>[ZI_0,`D?,+`/FS``#P8#I"N5GX_Y?L__^78#I"N5;X_Y?S"T#Y!```
MT`(``-"$`"J1`0``T/U[PJCC`P2J0D`$D2'@')$%`(!2J_C_%_\+0-'_PP#1
M_7N]J?T#`)'U$P#YM0``\/-3`:F@(@F1`0!`^:$O$/D!`(#2#_C_EZ1#`)$"
M"H320@`$B^$"A))!``&+!0``T`,``-#D`P`JI4`=D>`#`:IC8!V1H1\`^2(`
M@M(A`(!2S/?_EV`$^#>C0P"1`@J$TD(``XN@'T#YX0&"DD$``8L"`(+2H1\`
M^<[W_Y?S`P"J``/X-P`$`!$`?$"3]??_E_0#`*I@`@"T<WY`DZ$?0/GB`Q.J
MI_?_EY]J,SC@`Q2JM2()D:(O4/FA`D#Y00`!RD$!`+7S4T&I]1-`^?U[PZC_
M"T"1_\,`D<`#7]8?(`/5``"`TO/__Q<6^/^7'R`#U;[__Q<?(`/5_P=`T0,`
M`-#_@P#18@&"DOU[NZG]`P"1\U,!J?0#`*KS`P&J8,`=D0$,@M*C0P"1]5L"
MJ2$``XOW8P.IM@``\/EK!*DA``*+PB()D4,`0/FC-PCY`P"`TMC]_Y?U`P"J
MX`,4JN$%@%)0^/^78`(`M````-#A`Q2J```>D3'^_Y?@`Q2JUB()D:(W2/G!
M`D#Y00`!RH$+`+7S4T&I]5M"J?=C0ZGY:T2I_7O%J/\'0)'_@P"1P`-?UN`#
M%*H8``#0;O?_E_D#`"H!0QZ1X`,3JF;W_Y?S`P"JP/S_M!<``-`:``#0]Z(=
MD3D'`!%:8QZ18`)`.1\`'VMS$I>:M0``M.$#$ZK@`Q6J]/?_EZ`%`#3@`Q.J
M6??_E^$#`"I@PB"+`/!?.!^\`''A``!4(00`46#"(8M_RB$X`/!?.!^\`'%@
M__]4(0,!"S_\/W$L^?]4HD,`D0$,@M(A``*+X`""D@,``+`@``"+Y`,3JN8#
M%*KE`QJJ8X`>D0(`@M(A`(!2LP``T*`O`/E`]_^78#I"N:+W_Y<"X`>1H2]`
M^0``@%)"]_^7X```-6`Z0KF;]_^7``A"N0`,%!(?($!QX```5`%#'I$``(#2
M*/?_E_,#`*H`^?^UI___%Z`O0/DA`(!2KO?_E^#^_S6A+T#Y````L```'I'3
M_?^7H"]`^4?W_Y>A__\7D??_EP$`0#G!```T`@0`D3^\`'$`$(*:011`.*'_
M_S7``U_6_7N^J?T#`)'S4P&I8`,`M!0`0#GS`P"J%`,`-`WW_Y<`!`#18@(`
MBW\"`NMB!`!48&I@.!^\`'&@``!4'```%$``0#D?O`!Q(0,`5$($`-%_`@+K
M8?__5)^^`''@``!4\U-!J0```+#]>\*H`&`>D2#W_Q<?(`/50`"`TC'W_Y=`
M!0"T`@``L$*@'9%"`$!Y`@``>?-30:G]>\*HP`-?UD``0#D?O`!Q@`$`5$($
M`-%_`@+K8___5'\"`NO@_/]40@0`T7\"`NOB``!40`!`.1^\`'&!``!40@0`
MT7\"`NMC__]40@`3RT`(`)$?!$#QR`$`5*```-#A`Q.J`(`)D4($`)$3(`"1
M`P""TN`#$ZH0]_^7X`,3JO-30:G]>\*HP`-?UA\@`]4``(#2\U-!J?U[PJC`
M`U_6_7NXJ0$``+`AP!B1````L/T#`)'S4P&ILP``T/5;`JEC(@F1]QL`^0"@
M'I$F'$&I8@!`^:(_`/D"`(#2)!1"J:8?!:DA8$!Y%0``L*07!JD6``"PH>,`
M>1<``+`4``"P./W_EY0B()$```"P`.`>D33]_Y<```"P```?D3']_Y<```"P
M`$`?D2[]_Y>@8A^1+/W_EP```+``H!^1*?W_E\#"'9$G_?^7X.(?D27]_Y?@
M`Q2J(_W_EP```+``8""1(/W_EP```+```!Z1'?W_EP```+``H""1&OW_EP``
M`+``X""1%_W_EP```+"A,P&1`"`AD=G\_Y>```"TX0,`JN`#%*HW_?^7````
ML*$S`9$`@"&1T?S_EZ```+0"``"PX0,`JD#@(9$N_?^7````L*$S`9$`("*1
MR/S_EV`"`+3A`P"JP,(=D2;]_Y<!``"PH&(?D2$`(Y%S(@F1(?W_EZ$_0/E@
M`D#Y(```RF`#`+7S4T&I]5M"J?<;0/G]>\BHP`-?UA\@`]4```"PH3,!D0!@
M(I&Q_/^7P```M.$#`*K@XA^1#_W_E^G__Q<?(`/5`0``L*"'`9$AP"*10@&`
MTJ+V_Y=`_/\UH:\!D>#B'Y$$_?^7WO__%\3V_Y<?(`/5_7N]J?T#`)'S4P&I
MM```T+,``-!@(@F1`0!`^:$7`/D!`(#2@")"N1\$`#$@`0!4<R()D:(70/EA
M`D#Y00`!RJ$"`+7S4T&I_7O#J,`#7]8```"PH9,`D0#@'Y&'_/^70`$`M`$`
M0#D_P`!QX@>?&C\`'VO@!Y\:0```"H`B`KGL__\7'R`#U0``@%*`(@*YZ/__
M%YWV_Y?]>[^I_0,`D3KV_Y?!]O^7@```M```0/G]>\&HP`-?U@``@-+]__\7
M`0``L/U[MJDAP!B1_0,`D?-3`:GU6P*I]@,`JC.80ZGW8P.I(>``D?EK!*FW
M``#0LQL&J>(B"9$@&$#Y0P!`^:-/`/D#`(#2)!1!J:!+`/DB#$*II!<'J:(/
M"*D3`P"T`0``L````+"UHP&1.4`>D1B`'I$&```4X0,6JNOV_Y=``P"TLX9`
M^+,!`+2A<P&1X`,3JDG\_Y?T`P"J8```M`$`0#FA_O\UX`,3JN$#%JJD_/^7
MLX9`^+/^_[7W(@F1H4]`^>`"0/D@``#*8`,`M?-30:GU6T*I]V-#J?EK1*G]
M>\JHP`-?UN`#%JKC]?^7^@,`JN`#%*K@]?^70`,`BP`(`)$9]O^7^@,`JN8#
M%*KE`QFJY`,6JN,#&*H"`("2(0"`4MGU_Y?A`QJJX`,3JH3\_Y?4__\71/;_
MEQ\@`]7_(T#1"C20TO^#!='I'Y"2`@``L.@ED))"P!B182:0DOU[NJE$(`*1
M1>`"D>,BD)+]`P"1JX,`D?5;`JE*`0N+]0,`JDD!"8L`-)#2J3\`^0DTD-(I
M`0N+```+BR@!"(L!``&+J#L`^0@TD-)&'$>I]V,#J4!`0/D(`0N+HCM`^0,!
M`XOY:P2IN```T/-3`:D:``"P^W,%J?]#`-%&'`"I0`@`^:(_0/F&'$"IH`A`
M^:@D0*E&'`"I8`@`^4##'9&&'$&I:"0`J8(,0JFD/T#YAAP!J:0_0/F"#`*I
M`S.0T@(C"9%C``N+1`!`^60``/D$`(#2X?O_EX```+0!`$`Y\P,`JF$A`#5D
M__^7]`,`JH`A`+3@`Q2JB/7_EP#X?],`!`"1P?7_EQ<``+"$`D`Y]@,`JO,#
M`*KW0B.1)`$`-.`#$ZKC`Q>J`@"`DB$`@%)S"@"1??7_EX0>0#@D__\UHH,`
MD0$TD-*@8T#Y(0`"B_0?D))W)I"2-``4BP$TD-(A``*+-P`7BX```+4/```4
M@(Y`^*`!`+3A`Q>JM_O_E_,#`*I@__^T`0!`.2'__S3T_/^7X/[_-.`#$ZJ'
M]?^7\P,`J@`#`+6S2T#YLPH`M&`"0#DT`(!2@`$`-5$``!0`-)#2H8,`D0``
M`8L`S#2+`"1`T1-H1_E3"0"T8`)`.90&`!'@"``TX`,3JMW\_Y>`_O\TX`,3
MJG#U_Y?S`P"J`/[_M.`#$ZH9``"P0_7_E_0#`*K@`Q:J0/7_EP``%`L7$!`1
M]WY`D^`#%ZIW]?^7]`,`J@8``+`#``"PYP,6JL9@(Y'D`Q.J8X`CD25C'I$"
M`("2(0"`4C3U_Y?@`Q2J`3B`4B7V_Y<?!``QX`0`5+,``-!@.D*YD/7_EP+@
M!Y'A`Q2J``"`4M#U_Y>@!0`TH```T`(``+"C`D#YY`,4JD+@)9$A`(!2`!A!
M^:_U_Y<``(#2HH,`D0$SD-(8(PF1(0`"BR(`0/D!`T#Y00`!RH$_`+6_`P"1
M\U-!J?5;0JGW8T.I^6M$J?MS1:G]>\:H_R-`D?^#!9'``U_6'R`#U1,`@-+`
M__\7]/7_EP4`0+F_1`!QX/K_5*```-`"``"PHP)`^>0#%*I"P".1(0"`4@`8
M0?F-]?^7``"`TM[__Q=@.D*Y7?7_EP`(0KD`#!02'Q!`<>'Y_U1@.D*Y5_7_
MEQ800KD!]?^7WP(`:R'Y_U1@.D*Y4?7_EP`(0KD`(``2'P`'<6'X_U3@`Q>J
M'_7_E_,#`*H"-)#2HX,`D6$FD)(```"P0@`#BP#@*Y%!``&+*OO_ER`/`+2V
M`D#Y__3_E^$#`*K@`Q:J-OW_E_8#`*I`#@"TX`,6JM#T_Y<?#`!Q]P,`JNT!
M`%0`?$"3`0``L``0`-$AP"21P`(`BU_U_Y<``0`U_Q(`<4`M`%3@$@!1P,(@
MBP#P7S@?O`!QH"P`5'#^_Y?````UX`,6J@$`@%*:]?^7^P,`*D`+`#4!``"P
M````L"$`(Y$`X!^1.6,>D18``+`5`(!2UH(ED6'[_Y?F]/^7Y@,`*@<``+`#
M``"PYP`JD>4#&:IC0"61Y`,4JN`#$ZH"`("2(0"`4O<#!ZJF]/^7$0``%)#U
M_Y<``$"Y'T0`<4$"`%34]/^7M08`$>8#`"KG`Q4JY0,9JN0#%*KC`Q:JX`,3
MJ@(`@)(A`(!2]P,`^97T_Y?@`Q.J`3B`4H;U_Y<?!``Q@/W_5.`#%*H^]?^7
MX0,3JD##'9$Y^_^7X`,3JF?^_Y?@`Q.J:O__%V3^_Y?@`Q.JJ/3_EV;__Q>A
M@P"1`#20T@```8OV(I"2%@`6BP`TD-)W)I"2```!BQ<`%XL3`(#28&IV^,`!
M`+3A`Q>JP?K_EV```+0!`$`Y@0``-7,B`)'X__\7'R`#U9+T_Y?T`P"JX-O_
MM7,B`)'R__\7%```L*`!@-*4(B.1W?[_%Q\@`]6V`D#YCO__%T(`@%(A`H"2
MO/3_EZ*#`)$!-)#2(0`"B^``D)(@``"+P@"`TJ`_`/G@`QLJH3]`^2KU_Y>@
MXT8Y@```-:#G1CD?#`%QX"(`5.`#&RH"`(!2`0"`TO<9D)*H]/^7O_\1J2%@
MA-(@<972H>BL\J#YO?+"GYO2OVL!N:$##ZG!CHK2`#Z<TD(7L_)!!J+R0'JX
M\J*#`/FB@P"1H8,0J0$TD-(A``*+-P`7B^#B`)&@/P#YH>,&D>`#&RH"`)#2
M!_7_EQ\`'VO\`P"J]0,`*FT)`%2BCT#Y@']`DT$,``M?``'KHI-`^4D``%1"
M!`"10'1`BZ&#$:F@:T&Y`!@`-!4(@%*A/T#YM0(`2Y\#%6N5TY4:(,`@BZ'C
M!I&V?D"3X@,6J@KT_Y>@:T&YH`(`"Q\``7&@:P&YX?O_5*#C!I&5`Q5+'``6
MB^`#%ZKB]?^7O_X`<<T7`%2@`@%1`320TJ*#`)'J$I"2(0`"BS4`"HL!?`93
MH(<-*>`#`:H69'K3U@(!D98#%HN&'T"IX`,7JH070:FF'@"I@@]"J:06`:F(
M)T.IH@X"J:@F`ZF<`P&1R?7_E]\"'.N!_O]4H8--*348`$N@/T#YHGY`D^$#
M%JH#"8#2'O3_E[5K`;FAXP:1X`,;*@(`D-*]]/^7'P`?:_P#`*KU`P`J[/;_
M5.`#&RI7]/^7M=M1J:$#.='B#X`2H")#TR'`((L`!``1'^``<2*@/3F,$0!4
M`S20TJ2#`)$"!X!2X1*0DF,`!(M"``!+80`!BT)\0),@P""+`0"`4A_T_Y>C
M@P"1`320TB$``XO@&9"2POY8TR```(O!_E#3MH\%.:*#!3G6_DC3HOY8TZ&'
M!3FUGP4YH?Y0T[7^2-.VBP4YHI,%.?8&D)*AEP4Y%P``L+6;!3F+]?^7I0]/
MJ:>#`)$&-)#2I<\%.<8`!XNCWP4YU@`6BZ1\6-.F_%#3I?Q(TZ('4*FERP4Y
M9?Q8TZ+O!3F@BT#YVPF0DJ73!3EE_%#38_Q(TZ'_!3F@#P8Y]4(CD:/;!3E#
M_%C3UZ(`D:3#!3FCXP4Y0_Q0TT+\2-.FQP4YI=<%.:+K!3DB_%C3H^<%.:+S
M!3DB_%#3(?Q(TZ+W!3D"_%C3H?L%.0'\4-.B`P8Y`/Q(TP(TD-*A!P8Y0@`'
MBZ`+!CE;`!N+`P``%!\@`]5D%T`XX`,6JN,#%:H"`("2(0"`4M8*`)&`\_^7
M_P(6ZP'__U2A@P"1`#20T@```8L'``"PY@:0D@,``+`&``:+YP`JD25C'I'D
M`Q2J8P`ED>`#$ZH"`("2(0"`4K_#!CEN\_^7X`,4JAST_Y?A`Q.J0,,=D1?Z
M_Y?@`Q.J1?W_E^`#$ZI(_O\7H8,`D0`TD-(```&+X0"0DAP``8M0__\7M09`
M^773_[3@`Q6J5_/_EQ\,`/'ITO]4`!``T0$``)`AX"21H`(`B^CS_Y<?`!]K
MUA*5FH_^_Q?V`QRJ7?__%Z2#`)$#-)#28P`$B^$9D))A``&+`@B`4C?@`)%"
M``!+H3\`^0$`@%)"?$"3X,(@BY+S_Y>@/T#Y$O7_E_]^`*G_?@&I_WX"J?\:
M`/EM__\7H.M&.1\$`7$!W?]4H.]&.1\,`7&AW/]4H/-&.1\@`7%!W/]4H/=&
M.1\4`7'AV_]4X`,;*D(`@%(A!X"2A_/_EZ$_0/G@`QLJ(@6`TOOS_Y<'``"0
M`P``D*8_0/GG`"J1)6,>D>0#%*IC`"61X`,3J@(`@)(A`(!2'//_EXS^_Q>*
M\_^7'R`#U?U[N:F@``"P`"`)D?T#`)'Y:P2IN0``L/-3`:GU6P*I]V,#J?MS
M!:D!`$#YH3<`^0$`@-(@.T*Y;O/_ER,`@%("``"0H9,!D0/$`CE`8!^14/G_
MEX```+0!`$`Y/\0`<<`0`%0U_/^7(#M"N;L``-!@\_^7`0``D&,!@%(A0">1
M(@"`4F_S_Y>@!@"T=8,-D0$(0/F@@E"X-Q1`^1\$`''M!0!4&("`4C;C")$4
M`(!2,P"`4A@$H'(+```4'R`#U2$(0/G@`QJJ>O/_E^`#`#6@@E"X<P8`$90&
M`!$?`!-KC0,`5,`"0+E"\_^7@GY`D^$#%ZH#`(!2IO/_E_P#`*I``@"T`0!`
M^:("4?@@#$"Y6MAS^```&`H?`!!Q(/W_5,`"0+DS\_^7@0-`^4,`@%("`(#2
M'_/_E^$#`*K@`QJJ7//_EV#\_S1@@PV1`(!0N`$$`%$_`!1K@`D`5"`[0KDD
M\_^7`0``D&,`@%(A8">1(@"`4C/S_Y?S`P"J@`$`M"`[0KD;\_^780I`^0(`
M`)!"@">1(0!`^?;R_Y=@"D#Y``!`^0`,0+D@$+`W(#M"N1#S_Y<!``"08P"`
M4B&@)Y$B`(!2'_/_E_,#`*J@`0"T````D*&3`9$``!Z1[?C_E_0#`*H@.T*Y
M%`L`M`'S_Y=A"D#YX@,4JB$`0/G=\O^7(#M"N76##9'Z\O^7'\0".0(``)"A
MDP&10,`=D=WX_Y>@@A'X]`,`JL`$`+0!.(!2@//_EP$$`!$_!`!Q!(A1>J$,
M`%2@``"P&B`)D:$W0/E``T#Y(```RL`+`+7S4T&I]5M"J?=C0ZGY:T2I^W-%
MJ?U[QZC``U_6``1`.6#O_S1Y__\7'R`#U1\$`'&-]O]4->,(D72##9$S`(!2
MH`)`N7,&`!'3\O^7X0,7JH7R_Y>`@E"X'P`3:RS__U2H__\7H`)1^)7\_Y>@
M@A'XP`<`M&$*0/D`@(!2``2@<B$`0/DB#$"Y0```"A\`$'$!!0!4(`A`^7N#
M#9%T`U'XX0,4JN3R_Y?U`P`J80I`^0"`@%(`!*!RE`)`^2$`0/DB#$"Y0```
M"A\`$'$!`@!4(@A`^0```)#C`Q4JX0,4J@!@*)'H\O^7'R`#U:KR_Y=@@PV1
M8@I`^0$`4?A``$#Y(0!`^?+Y_Y>G__\7(#M"N:'R_Y=A"D#Y`@"`TD,`@%(A
M`$#YC/+_E^(#`*KJ__\7(#M"N9CR_Y=A"D#Y0P"`4@(`@-(A`$#Y@_+_E]/_
M_Q<@.T*YD/+_EV$*0/DA`$#YY?+_EWO__Q<```"0`,`GD<7R_Y>4\O^7H0)1
M^`0``)#C`P`JX@,4JH``*9$A`$#YO?+_E_U[OJG]`P"1\U,!J?0#`*H`^_^7
M\P,`J@``0#G````T808`D1^\`'%S$H&:(!1`.*#__S6]^_^7GP(?ZP007WH@
M`0!4@`)`.>```#0!``"0X`,3JB%@(Y'N\O^7?P(`ZX```%3S4T&I_7O"J,`#
M7];@`Q2J\U-!J?U[PJ@S^?\7HP``L&1@")%D``"T8PQ!^1CR_Q<#`(#2%O+_
M%_U[O*G]`P"1\U,!J?5;`JFT``"0M0``D+4"-Y&4(C>1E`(5R_8#`JJ4_D.3
M$P"`TO=C`ZGX`P`J]P,!JLCQ_Y<T`0"THWIS^.(#%JKA`Q>JX`,8*G,&`)%@
M`#_6?P(4ZR'__U3S4T&I]5M"J?=C0ZG]>\2HP`-?UL`#7];]>[^I_0,`D?U[
MP:C``U_6`0`"``````!P97)L>'-I+F,`````````7U]%3E9?4$%27T-,14%.
M7U\@("`@("`@("`@("`@("```````````-A:0```````Z%I```````#P6D``
M`````/A:0````````%M````````86T``````````````````T%I```````!H
M5T``````````````````>%A```````"P6D```````+A:0```````P%I`````
M``#(6D``````````````````F%I```````"@6D``````````````````)7,O
M)7,````O<')O8R]S96QF+V5X90``1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A
M9&5R``````!);G1E<FYA;',Z.E!!4CHZ0D]/5`````!E>&4``````"]P<F]C
M+R5I+R5S```````N`````````%!!4E]414U0``````````!005)?4%)/1TY!
M344`````.@`````````O`````````"5S)7,E<P``4$523#5,24(`````````
M`%!%4DQ,24(`4$523#5/4%0``````````%!%4DQ)3P``4$%27TE.251)04Q)
M6D5$`%!!4E]34$%73D5$``````!005)?0TQ%04X`````````4$%27T1%0E5'
M`````````%!!4E]#04-(10````````!005)?05)'0P``````````4$%27T%2
M1U9?,````````%!!4E]'3$]"04Q?1$5"54<``````````%!!4E]'3$]"04Q?
M5$U01$E2`````````%!!4E]435!$25(```````!005)?1TQ/0D%,7U1%35``
M4$%27T=,3T)!3%]#3$5!3@``````````4$%27T-,14%./0```````#$`````
M````4UE35$5-```E,#)X`````'!A<BT`````)7,E<R5S)7,``````````"5S
M.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@
M*&5R<FYO/25I*0H```````!P87)L`````"YP87(`````)7,E<V-A8VAE+25S
M)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S```````````E
M<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@
M<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*````````05)'
M5@`````8`````````'!E<FP`````,`````````!5;F%B;&4@=&\@8W)E871E
M(&-A8VAE(&1I<F5C=&]R>0``````````)7,Z(&5X96-U=&EO;B!O9B`E<R!F
M86EL960@*&5R<FYO/25I*0H``"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A
M8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````````
M`"UE````````+2T```````!54T52`````%5315).04U%``````````!435!$
M25(``%1%35!$25(`5$5-4`````!435```````"]T;7``````3$1?3$E"4D%2
M65]0051(`$Q)0E!!5$@`3$E"4D%265]0051(`````$193$1?3$E"4D%265]0
M051(`````````%-(3$E"7U!!5$@```````!E=F%L("=E>&5C("]U<W(O8FEN
M+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U
M;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R7W1E
M;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?
M0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL
M93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO
M=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD
M9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T
M96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>
M3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I4
M14U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z
M.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]
M/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD
M>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@
M)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@
M7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*
M8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I
M;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y
M<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S
M<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*
M?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D
M("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H
M*3L*:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!
M4D=67S!]("D@>PI`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H
M,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PHD,"`]("1%3E9[4$%27T%21U9?
M,'T["GT*96QS92!["F9O<B`H:V5Y<R`E14Y6*2!["F1E;&5T92`D14Y6>R1?
M?2!I9B`O7E!!4E]!4D=67R\["GT*?0IM>2`D<75I970@/2`A)$5.5GM005)?
M1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^
M("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]
M?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E
M;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G
M*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D
M<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).7U]]
M(#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*
M8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G;F%M
M93L*;7D@)&]F9G-E="`](#4Q,CL*;7D@)&ED>"`]("TQ.PIW:&EL92`H,2D*
M>PHD;V9F<V5T(#T@)'-I>F4@:68@)&]F9G-E="`^("1S:7IE.PIS965K(%]&
M2"P@+21O9F9S970L(#(@;W(@9&EE('%Q6W-E96L@9F%I;&5D(&]N("(D<')O
M9VYA;64B.B`D(5T["FUY("1N<F5A9"`](')E860@7T9(+"`D8G5F+"`D;V9F
M<V5T.PID:64@<7%;<F5A9"!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A72!U
M;FQE<W,@)&YR96%D(#T]("1O9F9S970["B1I9'@@/2!R:6YD97@H)&)U9BP@
M(EQN4$%2+G!M7&XB*3L*;&%S="!I9B`D:61X(#X](#`@?'P@)&]F9G-E="`]
M/2`D<VEZ92!\?"`D;V9F<V5T(#X@,3(X("H@,3`R-#L*)&]F9G-E="`J/2`R
M.PI]"FQA<W0@=6YL97-S("1I9'@@/CT@,#L*)&]F9G-E="`M/2`D:61X("T@
M-#L*<V5E:R!?1D@L("TD;V9F<V5T+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*
M<V5E:R!?1D@L("TD;V9F<V5T("T@=6YP86-K*").(BP@)&)U9BDL(#(["G)E
M860@7T9(+"`D8G5F+"`T.PHD9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*
M;7D@)7)E<75I<F5?;&ES=#L*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E
M860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@
M)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7$H56YP86-K:6YG
M(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE
M(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B
M87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ
M*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C
M:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O
M7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@*"1O=70L("1F:6QE;F%M92D@
M/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD["FEF("@D;W5T*2!["F)I;FUO9&4H
M)&]U="D["G!R:6YT("1O=70@)&)U9CL*8VQO<V4@)&]U=#L*8VAM;V0@,#<U
M-2P@)&9I;&5N86UE.PI]"B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN
M86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL
M96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\
M7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@
M)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%35!]+R1B87-E;F%M921E>'0B.PIO
M=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*;W!E;B!M>2`D;W5T+"`G/B<L
M("1F:6QE;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&]U="D["G!R:6YT("1O
M=70@)&)U9CL*8VQO<V4@)&]U=#L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD
M9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M
M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L
M;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]
M("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R
M968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&9I;&5N86UE(#T@9&5L971E
M("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PIM>2`D:V5Y.PIF;W)E
M86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*;F5X="!U;FQE<W,@+UQ1)&UO
M9'5L95Q%)"\["B1K97D@/2`D7SL@;&%S=#L*?0ID96QE=&4@)')E<75I<F5?
M;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PI](&]R(')E='5R;CL*)$E.
M0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*:68@
M*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI
M('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*
M8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*<V5E
M:R@D9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`H)&]U="P@
M)&YA;64I(#T@7W1E;7!F:6QE*"<N<&TG+"`D9FEL96YA;64M/GMC<F-]*3L*
M:68@*"1O=70I('L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U="`D9FEL96YA
M;64M/GMB=69].PIC;&]S92`D;W5T.PI]"F]P96X@;7D@)&9H+"`G/"<L("1N
M86UE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I
M92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A
M7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z
M.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R
M.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U
M:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y
M<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE
M?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]
M?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID
M;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ
M95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T[
M"GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P
M;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T
M+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[
M4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E
M8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%
M0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M
M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@
M8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R
M"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD
M("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM0
M05)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA
M;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6
M*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R
M(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#([
M"GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF
M("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF
M("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I
M('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B
M=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`]
M(#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@
M)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PI]"F5L<VEF
M("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'
M5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.
M5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z
M.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF
M="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER
M92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'!A<B`]
M('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PI!
M<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@Q,C@J,3`R-"D["F]P96X@;7D@
M)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A
M(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@
M9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R![
M"FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!
M+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S
M+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]
M"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!0
M05(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I
M.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E
M<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]
M($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)
M3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W
M-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@
M)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L
M(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?
M5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF;W)E86-H(&UY
M("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E]
M(&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO
M.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R([
M"FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D
M97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H
M;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT
M*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E
M(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!S;W)T
M('L*;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0I](&=R97`@>PHA+T)31%!!
M3B\*?2!G<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#
M;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*+UY?/"@N
M*RDD+R!A;F0@+64@)#$@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y<R`E.CH[
M"B1F:6QE<WLD7WTK*R!F;W(@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@
M)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C
M:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R
M96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@
M*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK
M+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-
M;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I
M.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M
M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S
M(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X
M="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%
M)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_
M("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E
M;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69]
M.PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG
M="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@
M/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE
M=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD
M9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T
M:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B
M+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE
M"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D[
M"B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(
M86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C
M:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM
M92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN
M97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ
M5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R
M("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T
M+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH
M;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I
M;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_
M("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B
M7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@
M+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I
M;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD
M9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W
M-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R
M=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0[
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH
M9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D
M1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C
M:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD
M<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]4
M14U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O
M<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@
M)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB
M97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*
M7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY
M("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P
M96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII
M9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E
M<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B
M('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI]
M(&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@
M(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D
M9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q
M(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;
M("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R
M(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R
M8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]
M('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@
M/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@
M)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M
M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z
M.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE
M<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@
M;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q
M=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*
M<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R
M<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG
M.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I
M<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U
M:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE
M=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*
M979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E
M($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z
M.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[
M(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F
M."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R
M7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P
M("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0
M(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S
M<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY
M("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W
M=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z
M.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE
M.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U
M:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%
M3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G
M.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N
M<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P
M<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I
M.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*
M:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y
M<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I
M<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS92![
M"FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T
M.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@
M/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S
M:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y
M)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D[
M"GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA
M;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO
M<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H
M92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["GT*
M8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%2
M7U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T
M.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6
M>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D
M97AT+"`D8W)C*2`]($!?.PIM>2`H)&9H+"`D9FEL96YA;64I.PHD9FEL96YA
M;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*:68@*"1%3E9[4$%27T-,14%.
M?2D@>PIU;FQI;FL@)&9I;&5N86UE(&EF("UE("1F:6QE;F%M93L*<'5S:"!`
M=&UP9FEL92P@)&9I;&5N86UE.PI]"F5L<V4@>PIR971U<FX@*'5N9&5F+"`D
M9FEL96YA;64I(&EF("@M<B`D9FEL96YA;64I.PI]"F]P96X@)&9H+"`G/B<L
M("1F:6QE;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<F5T=7)N*"1F
M:"P@)&9I;&5N86UE*3L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I
M;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345]
M(#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]
M("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@
M)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P
M<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K
M(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G
M;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F
M:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H
M+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D
M0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P
M;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE
M>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[
M4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL*
M*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#
M;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G
M;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T[
M"FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2![
M"B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM
M>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D
M*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W
M9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_
M/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM
M?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A
M<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@
M,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@
M/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(
M12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@)$5.5GLG4$%2
M7R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I
M('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I
M9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L
M96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@
M*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*
M96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D
M=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.
M(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?
M0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T
M.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92![
M"G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N
M9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O
M;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE
M>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]
M"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"90
M05(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7$H
M<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.
M;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA
M;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T52
M4D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)2
M3U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I
M9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````'@D0```````2"1```````````````````$`
M`````````0`````````!`````````,0!`````````0`````````3`@``````
M``$`````````9@,````````,`````````/@<0```````#0`````````85D``
M`````!D`````````P)U!```````;``````````@`````````&@````````#(
MG4$``````!P`````````"`````````#U_O]O`````&`"0```````!0``````
M```8$$````````8`````````$`9````````*`````````.4$````````"P``
M```````8`````````!4````````````````````#`````````.B?00``````
M`@`````````P!@```````!0`````````!P`````````7`````````,@60```
M````!P`````````X%D````````@`````````D``````````)`````````!@`
M````````_O__;P````#8%4```````/___V\``````P````````#P__]O````
M`/X40```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````V)U!````````````````````````````````````
M`````````````!`=0```````$!U````````0'4```````!`=0```````$!U`
M```````0'4```````!`=0```````$!U````````0'4```````!`=0```````
M$!U````````0'4```````!`=0```````$!U````````0'4```````!`=0```
M````$!U````````0'4```````!`=0```````$!U````````0'4```````!`=
M0```````$!U````````0'4```````!`=0```````$!U````````0'4``````
M`!`=0```````$!U````````0'4```````!`=0```````$!U````````0'4``
M`````!`=0```````$!U````````0'4```````!`=0```````$!U````````0
M'4```````!`=0```````$!U````````0'4```````!`=0```````$!U`````
M```0'4```````!`=0```````$!U````````0'4```````!`=0```````$!U`
M```````0'4```````!`=0```````$!U````````0'4```````!`=0```````
M$!U````````0'4```````!`=0```````$!U````````0'4```````!`=0```
M````$!U````````0'4```````!`=0```````$!U````````0'4``````````
M``````````````````#_____`````"A;0```````1T-#.B`H56)U;G1U+TQI
M;F%R;R`U+C,N,2TV=6)U;G1U,2D@-2XS+C$@,C`Q-C`Q,30`1T-#.B`H56)U
M;G1U+TQI;F%R;R`T+CDN,RTX=6)U;G1U,BD@-"XY+C,``"YS:'-T<G1A8@`N
M:6YT97)P`"YN;W1E+D%"22UT86<`+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N
M:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO
M;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O
M9&%T80`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+FIC<@`N
M9'EN86UI8P`N9V]T`"YG;W0N<&QT`"YD871A`"YB<W,`+F-O;6UE;G0`````
M````````````````````````````````````````````````````````````
M```````````````````````+`````0````(```````````)``````````@``
M`````!L````````````````````!````````````````````$P````<````"
M`````````!P"0```````'`(````````@````````````````````!```````
M`````````````"$````'`````@`````````\`D```````#P"````````)```
M``````````````````0````````````````````T````]O__;P(`````````
M8`)```````!@`@```````*P#````````!0`````````(````````````````
M````/@````L````"`````````!`&0```````$`8````````("@````````8`
M```!````"``````````8`````````$8````#`````@`````````8$$``````
M`!@0````````Y00```````````````````$```````````````````!.````
M____;P(`````````_A1```````#^%````````-8`````````!0`````````"
M``````````(`````````6P```/[__V\"`````````-@50```````V!4`````
M``!@``````````8````#````"````````````````````&H````$`````@``
M```````X%D```````#@6````````D``````````%``````````@`````````
M&`````````!T````!````$(`````````R!9```````#(%@```````#`&````
M````!0```!8````(`````````!@`````````?@````$````&`````````/@<
M0```````^!P````````4````````````````````!```````````````````
M`'D````!````!@`````````0'4```````!`=````````0`0`````````````
M`````!``````````$`````````"$`````0````8`````````4"%```````!0
M(0```````,@T```````````````````(````````````````````B@````$`
M```&`````````!A60```````&%8````````0````````````````````!```
M`````````````````)`````!`````@`````````H5D```````"A6````````
MN$(```````````````````@```````````````````"8`````0````(`````
M````X)A```````#@F`````````0````````````````````$````````````
M````````H@````X````#`````````,"=00``````P)T````````(````````
M````````````"````````````````````*X````/`````P````````#(G4$`
M`````,B=````````"`````````````````````@```````````````````"Z
M`````0````,`````````T)U!``````#0G0````````@`````````````````
M```(````````````````````OP````8````#`````````-B=00``````V)T`
M`````````@````````8`````````"``````````0`````````,@````!````
M`P````````#8GT$``````-B?````````$`````````````````````@`````
M````"`````````#-`````0````,`````````Z)]!``````#HGP```````"@"
M```````````````````(``````````@`````````U@````$````#````````
M`!"B00``````$*(````````@````````````````````"```````````````
M`````-P````(`````P`````````PHD$``````#"B````````6!``````````
M``````````@```````````````````#A`````0```#``````````````````
M```PH@```````%T````````````````````!``````````$``````````0``
M``,`````````````````````````C:(```````#J````````````````````
0`0``````````````````````
